// Demo of Grove - Starter Kit V2.0

// Define the pin to which the temperature sensor is connected.
const int pinTemp = A0;

// Define the B-value of the thermistor.
// This value is a property of the thermistor used in the Grove - Temperature Sensor,
// and used to convert from the analog value it measures and a temperature value.
const int B = 3975;

#include <Wire.h>
#include "rgb_lcd.h"

rgb_lcd lcd;

const int colorR = 0;
const int colorG = 128;
const int colorB = 255;

void setup()
{
    // Configure the serial communication line at 9600 baud (bits per second.)
    Serial.begin(115200);
        // set up the LCD's number of columns and rows:
    lcd.begin(16, 2);
    
    lcd.setRGB(colorR, colorG, colorB);
    
    // Print a message to the LCD.
    lcd.print("Grove TMP Sensor");

    delay(1000);
}

void loop()
{
    // Get the (raw) value of the temperature sensor.
    int val = analogRead(pinTemp);

    // Determine the current resistance of the thermistor based on the sensor value.
    float resistance = (float)(1023-val)*10000/val;

    // Calculate the temperature based on the resistance value.
    float temperature = 1/(log(resistance/10000)/B+1/298.15)-273.15;

    // Print the temperature to the serial console.
    Serial.print(temperature);
    Serial.println('C');    
    Serial.print(temperature * 1.8 + 32);
    Serial.println('F');
    Serial.println(' ');
    
    // set the cursor to column 0, line 1
    // (note: line 1 is the second row, since counting begins with 0):
    lcd.setCursor(0, 1);
    // print the number of seconds since reset:
    lcd.print("  Temp: ");
    lcd.print(temperature * 1.8 + 32);
    lcd.print("F  ");
    
    // Wait one second between measurements.
    delay(1000);
}

